﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Linq;

namespace LinqToSqlDbmlExample
{
	class Program
	{
		static void Main(string[] args)
		{
			Console.ReadLine();
		}

		private static void PrintProducts()
		{
			string connectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
			using (var context = new HealthyFoodContext(connectionString))
			{
				IEnumerable<Product> products = context.Brands
					.Where(b => b.ProducerID != 1)
					.SelectMany(b => b.Products);

				foreach (Product product in products)
				{
					Console.WriteLine("ProductID: {0}; Name: {1}", product.ProductID, product.Name);
				}
			}
		}

		private static void CreateProduct()
		{
			string connectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
			using (var context = new HealthyFoodContext(connectionString))
			{
				Brand brand = context.Brands.Single(b => b.BrandID == 5);
				var product = new Product
				{
					Name = "Шоколад Milka алпийско мляко",
					EnergyValue = 532,
				};
				brand.Products.Add(product);

				context.SubmitChanges();

				Console.WriteLine("Created product ID: {0}", product.ProductID);
			}
		}

		private static void UpdateProduct()
		{
			string connectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
			using (var context = new HealthyFoodContext(connectionString))
			{
				Product product = context.Products.Single(p => p.Name == "Шоколад Milka алпийско мляко");
				product.Proteins = (decimal)6.8;
				product.Fats = (decimal)29.6;
				product.Carbohydrates = (decimal)58;

				context.SubmitChanges();

				Console.WriteLine("Product updated");
			}
		}

		private static void DeleteProduct()
		{
			string connectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
			using (var context = new HealthyFoodContext(connectionString))
			{
				Product product = context.Products.Single(p => p.Name == "Шоколад Milka алпийско мляко");
				context.Products.DeleteOnSubmit(product);

				context.SubmitChanges();

				Console.WriteLine("Product deleted");
			}
		}
	}
}
